@@ -1,7 +1,14 @@
-pub use crate::error::EncodeError as Error;
+//! encode module
+
+use core::convert::TryFrom;
 use crate::core::{ types, major, marker };
+pub use crate::error::EncodeError as Error;
 
 
+/// Write trait
+///
+/// This is similar to `Write` of standard library,
+/// but it can define its own error type and work in `no_std`.
 pub trait Write {
     #[cfg(feature = "use_std")]
     type Error: std::error::Error + 'static;
@@ -9,10 +16,13 @@ pub trait Write {
     #[cfg(not(feature = "use_std"))]
     type Error: core::fmt::Display + core::fmt::Debug;
 
+    /// write all data
     fn push(&mut self, input: &[u8]) -> Result<(), Self::Error>;
 }
 
+/// Encode trait
 pub trait Encode {
+    /// Write the type to writer by CBOR encoding.
     fn encode<W: Write>(&self, writer: &mut W) -> Result<(), Error<W::Error>>;
 }
 
