@@ -145,14 +145,6 @@ impl<'de, 'a, R: dec::Read<'de>> serde::Deserializer<'de> for &'a mut Deserializ
     #[inline]
     fn deserialize_bytes<V>(self, visitor: V) -> Result<V::Value, Self::Error>
     where V: Visitor<'de>
-    {
-        let v = <types::Bytes<&[u8]>>::decode(&mut self.reader)?;
-        visitor.visit_borrowed_bytes(v.0)
-    }
-
-    #[inline]
-    fn deserialize_byte_buf<V>(self, visitor: V) -> Result<V::Value, Self::Error>
-    where V: Visitor<'de>
     {
         match <types::Bytes<Cow<[u8]>>>::decode(&mut self.reader)?.0 {
             Cow::Borrowed(buf) => visitor.visit_borrowed_bytes(buf),
@@ -161,15 +153,14 @@ impl<'de, 'a, R: dec::Read<'de>> serde::Deserializer<'de> for &'a mut Deserializ
     }
 
     #[inline]
-    fn deserialize_str<V>(self, visitor: V) -> Result<V::Value, Self::Error>
+    fn deserialize_byte_buf<V>(self, visitor: V) -> Result<V::Value, Self::Error>
     where V: Visitor<'de>
     {
-        let v = <&str>::decode(&mut self.reader)?;
-        visitor.visit_borrowed_str(v)
+        self.deserialize_bytes(visitor)
     }
 
     #[inline]
-    fn deserialize_string<V>(self, visitor: V) -> Result<V::Value, Self::Error>
+    fn deserialize_str<V>(self, visitor: V) -> Result<V::Value, Self::Error>
     where V: Visitor<'de>
     {
         match <Cow<str>>::decode(&mut self.reader)? {
@@ -178,6 +169,13 @@ impl<'de, 'a, R: dec::Read<'de>> serde::Deserializer<'de> for &'a mut Deserializ
         }
     }
 
+    #[inline]
+    fn deserialize_string<V>(self, visitor: V) -> Result<V::Value, Self::Error>
+    where V: Visitor<'de>
+    {
+        self.deserialize_str(visitor)
+    }
+
     #[inline]
     fn deserialize_option<V>(self, visitor: V) -> Result<V::Value, Self::Error>
     where V: Visitor<'de>
